@@ -1,6 +1,6 @@
 use std::mem::replace;
 
-use crate::plugins::{CorePlugin, PuffinPlugin};
+use crate::plugins::CorePlugin;
 use crate::schedulers::FixedUpdateScheduler;
 use crate::*;
 
@@ -169,7 +169,6 @@ impl Default for EngineBuilder {
             plugin_loader: PluginLoader::new(),
         }
         .with_plugin(Box::from(CorePlugin))
-        .with_plugin(Box::from(PuffinPlugin))
         .with_engine_core(Box::from(run_while_has_active_state))
     }
 }
