@@ -83,9 +83,29 @@ pub type Frames = u64;
 /// ```
 #[cfg_attr(test, automock)]
 pub trait Scheduler {
+    /// Profiles the [Scheduler::update()] method.
+    ///
+    /// **Warning:** This method is private API and SHOULD NOT be used by 3rd party code.
+    /// It is subject to change at any time without warning.
+    #[doc(hidden)]
+    fn profile_update(&mut self, context: &mut Context, state: &mut dyn State) {
+        puffin::profile_scope!("update");
+        self.update(context, state);
+    }
+
     /// Update the game state.
     fn update(&mut self, context: &mut Context, state: &mut dyn State);
 
+    /// Profiles the [Scheduler::render()] method.
+    ///
+    /// **Warning:** This method is private API and SHOULD NOT be used by 3rd party code.
+    /// It is subject to change at any time without warning.
+    #[doc(hidden)]
+    fn profile_render(&mut self, context: &mut Context, state: &mut dyn State) {
+        puffin::profile_scope!("render");
+        self.render(context, state);
+    }
+
     /// Render the game state.
     fn render(&mut self, context: &mut Context, state: &mut dyn State);
 }
